# Breach Check

Your email's silent protector: an easygoing tool that checks a list of emails for breaches. Just share the emails, and it works its magic.

## PyPi Downloads

| Period |                                                                                                      Count                                                                                                       |
| :----: | :--------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------: |
| Weekly | [![Downloads](https://static.pepy.tech/personalized-badge/breach-check?period=week&units=international_system&left_color=black&right_color=orange&left_text=Downloads)](https://pepy.tech/project/breach-check)  |
| Monthy | [![Downloads](https://static.pepy.tech/personalized-badge/breach-check?period=month&units=international_system&left_color=black&right_color=orange&left_text=Downloads)](https://pepy.tech/project/breach-check) |
| Total  | [![Downloads](https://static.pepy.tech/personalized-badge/breach-check?period=total&units=international_system&left_color=black&right_color=orange&left_text=Downloads)](https://pepy.tech/project/breach-check) |

## Join Our Discord Community

[![Join our Discord server!](https://invidget.switchblade.xyz/DJrnAg4nv2)](http://discord.gg/DJrnAg4nv2)

## Installation

### Using pip

-   Install main branch using pip

    ```bash
    python3 -m pip install git+https://github.com/dmdhrumilmistry/breach-check.git
    ```

-   Install Release from PyPi

    ```bash
    python3 -m pip install breach-check
    ```

### Manual Method

-   Open terminal

-   Install git package

    ```bash
    sudo apt install git python3 -y
    ```

-   Install [Poetry](https://python-poetry.org/docs/master#installing-with-the-official-installer)

-   clone the repository to your machine

    ```bash
    git clone https://github.com/dmdhrumilmistry/breach-check.git
    ```

-   Change directory

    ```bash
    cd breach-check
    ```

-   Install with poetry

    ```bash
    # without options
    poetry install
    ```

### Open In Google Cloud Shell

-   Temporary Session  
    [![Open in Cloud Shell](https://gstatic.com/cloudssh/images/open-btn.svg)](https://shell.cloud.google.com/cloudshell/editor?cloudshell_git_repo=https%3A%2F%2Fgithub.com%2Fdmdhrumilmistry%2Fbreach-check&ephemeral=true&show=terminal&cloudshell_print=./LICENSE)
-   Perisitent Session  
    [![Open in Cloud Shell](https://gstatic.com/cloudssh/images/open-btn.svg)](https://shell.cloud.google.com/cloudshell/editor?cloudshell_git_repo=https%3A%2F%2Fgithub.com%2Fdmdhrumilmistry%2Fbreach-check&ephemeral=false&show=terminal&cloudshell_print=./LICENSE)

## Have any Ideas 💡 or issue

-   Create an issue
-   Fork the repo, update script and create a Pull Request

## Contributing

Refer [CONTRIBUTIONS.md](/.github/CONTRIBUTING.md) for contributing to the project.

## LICENSE

breach-check is distributed under `MIT` License. Refer [License](/LICENSE) for more information.

## Connect With Me

|                                                                                                                       |                                                       Platforms                                                       |                                                                                                                                        |
| :-------------------------------------------------------------------------------------------------------------------: | :-------------------------------------------------------------------------------------------------------------------: | :------------------------------------------------------------------------------------------------------------------------------------: |
|       [![GitHub](https://img.shields.io/badge/Github-dmdhrumilmistry-333)](https://github.com/dmdhrumilmistry)        | [![LinkedIn](https://img.shields.io/badge/LinkedIn-Dhrumil%20Mistry-4078c0)](https://linkedin.com/in/dmdhrumilmistry) |             [![Twitter](https://img.shields.io/badge/Twitter-dmdhrumilmistry-4078c0)](https://twitter.com/dmdhrumilmistry)             |
| [![Instagram](https://img.shields.io/badge/Instagram-dmdhrumilmistry-833ab4)](https://instagram.com/dmdhrumilmistry/) |     [![Blog](https://img.shields.io/badge/Blog-Dhrumil%20Mistry-bd2c00)](https://dmdhrumilmistry.github.io/blog)      | [![Youtube](https://img.shields.io/badge/YouTube-Dhrumil%20Mistry-critical)](https://www.youtube.com/channel/UChbjrRvbzgY3BIomUI55XDQ) |
